@@ -11,8 +11,8 @@ config() {
   # Otherwise, we leave the .new copy for the admin to consider...
 }
 
-config etc/dbus-1/system.d/newprinternotification.conf.new
-config etc/dbus-1/system.d/printerdriversinstaller.conf.new
+config etc/dbus-1/system.d/com.redhat.NewPrinterNotification.conf.new
+config etc/dbus-1/system.d/com.redhat.PrinterDriversInstaller.conf.new
 
 # Update the desktop database:
 if [ -x usr/bin/update-desktop-database ]; then
